##  Importing Diagrams from Another Diagram
You can reuse an existing diagram by importing it into a new or existing free draw diagram. When you import a diagram, its contents are added to the editor as editable shapes. This option is only available in the free draw editor.
To import a diagram, do the following:
  1. Go to the Diagrams tab, and choose New Diagram or open an existing diagram.
  2. Choose Import Diagrams in the toolbar or choose File > Import from in the menu.
  3. Choose Diagrams to browse diagrams in your workspace.
  4. Select the diagram that you want to import, and choose Add. ![The import diagrams dialog showing a selection of diagram thumbnails to import.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio45bf0b557d714dc9b5525610af0a0938_LowRes.jpg)
